==> mingw-w64-itk-5.2.1-6.src.tar.zst: InsightToolkit-5.2.1/Modules/IO/NIFTI/test/BigEndian_hdr.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef __BigEndian_hdr_h
#define __BigEndian_hdr_h

static unsigned char BigEndian_hdr[] = {
  0, 0,  1,   92, 70, 76, 79,  65, 84, 0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  64, 0,   0,  0,  114, 0,   0, 4, 0,  6,   0, 6, 0,  8,   0,   1, 0, 1,  0,   1, 0, 1,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 16, 0,   5, 0, 0,  63,  128, 0, 0, 63, 128, 0, 0, 63, 128, 0,
  0, 63, 128, 0,  0,  63, 128, 0,  0,  63,  128, 0, 0, 63, 128, 0, 0, 63, 128, 0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   1, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0
};

#endif

==> mingw-w64-itk-5.3.0-2.src.tar.zst: InsightToolkit-5.3.0/Modules/IO/NIFTI/test/BigEndian_hdr.h <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         https://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef BigEndian_hdr_h
#define BigEndian_hdr_h

static unsigned char BigEndian_hdr[] = {
  0, 0,  1,   92, 70, 76, 79,  65, 84, 0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  64, 0,   0,  0,  114, 0,   0, 4, 0,  6,   0, 6, 0,  8,   0,   1, 0, 1,  0,   1, 0, 1,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 16, 0,   5, 0, 0,  63,  128, 0, 0, 63, 128, 0, 0, 63, 128, 0,
  0, 63, 128, 0,  0,  63, 128, 0,  0,  63,  128, 0, 0, 63, 128, 0, 0, 63, 128, 0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   1, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,
  0, 0,  0,   0,  0,  0,  0,   0,  0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0,   0, 0, 0,  0,   0, 0, 0,  0,   0
};

#endif
